@@ -46,9 +46,10 @@ adapt_draw_random_pattern ()
 
 	special = (accur_error_total () > ERROR_LIMIT);
 	if (special)
-		gtk_widget_show (get_wg ("kadro_tro_eraroj"));
+		gtk_widget_show (get_wg ("togglebutton_toomuch_errors"));
 	else
-		gtk_widget_hide (get_wg ("kadro_tro_eraroj"));
+		gtk_widget_hide (get_wg ("togglebutton_toomuch_errors"));
+	special = special && gtk_toggle_button_get_active (get_wg ("togglebutton_toomuch_errors"));
 
 	for (i = 0; i < LINES; i++)
 	{			/* paragraphs per exercise */
@@ -232,7 +233,7 @@ adapt_comment (gdouble accuracy)
 			       	tutor_goal_accuracy ());
 
 		accur_reset ();
-		gtk_widget_hide (get_wg ("kadro_tro_eraroj"));
+		gtk_widget_hide (get_wg ("togglebutton_toomuch_errors"));
 	}
 
 	wg = get_wg ("text_tutor");
