@@ -16,6 +16,7 @@
 #include "gtk/gtk.h"
 
 #include "auxiliar.h"
+#include "tutor.h"
 #include "cursor.h"
 
 struct
@@ -52,7 +53,6 @@ cursor_advance (gint n)
 	GtkTextIter new_start;
 	GtkTextIter old_start;
 	GtkTextIter end;
-	GtkAdjustment *scroll;
 	GtkTextMark *mark;
 
 	wg = get_wg ("text_tutor");
@@ -80,17 +80,13 @@ cursor_advance (gint n)
 	{
 		end = new_start;
 		gtk_text_iter_forward_line (&end);
+		//gtk_text_iter_forward_sentence_ends (&end, 3);
 		mark = gtk_text_buffer_create_mark (buf, "aux", &end, FALSE);
 		cursor_out_screen = gtk_text_view_move_mark_onscreen (GTK_TEXT_VIEW (wg), mark);
 		if (cursor_out_screen)
 		{
-			gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg),
-							    gtk_text_buffer_get_insert (buf));
-			wg = get_wg ("scrolledwindow_tutor_main");
-			scroll = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (wg));
-			gtk_adjustment_set_value (scroll,
-						  gtk_adjustment_get_value (scroll) + 8 * 23 *
-						  (n > 0 ? 1 : -1));
+			gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (wg),
+				       	gtk_text_buffer_get_insert (buf), 0.0, TRUE, 0.5, 0.12);
 		}
 	}
 	return (i);
@@ -221,7 +217,10 @@ cursor_switch_on ()
 	gtk_text_buffer_get_iter_at_mark (buf, &start, gtk_text_buffer_get_insert (buf));
 	gtk_text_buffer_get_iter_at_mark (buf, &end, gtk_text_buffer_get_insert (buf));
 	gtk_text_iter_forward_char (&end);
-	gtk_text_buffer_apply_tag_by_name (buf, "cursor_blink", &start, &end);
+	if (tutor_get_correcting () || tutor_get_type () != TT_FLUID)
+		gtk_text_buffer_apply_tag_by_name (buf, "cursor_blink", &start, &end);
+	else
+		gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &start, &end);
 }
 
 /**********************************************************************
@@ -241,5 +240,8 @@ cursor_switch_off ()
 	gtk_text_buffer_get_iter_at_mark (buf, &start, gtk_text_buffer_get_insert (buf));
 	gtk_text_buffer_get_iter_at_mark (buf, &end, gtk_text_buffer_get_insert (buf));
 	gtk_text_iter_forward_char (&end);
-	gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &start, &end);
+	if (tutor_get_correcting () || tutor_get_type () != TT_FLUID)
+		gtk_text_buffer_remove_tag_by_name (buf, "cursor_blink", &start, &end);
+	else
+		gtk_text_buffer_apply_tag_by_name (buf, "cursor_blink", &start, &end);
 }
