@@ -22,6 +22,7 @@
 
 #include "auxiliar.h"
 #include "main.h"
+#include "callbacks.h"
 #include "translation.h"
 #include "keyboard.h"
 #include "tutor.h"
@@ -66,6 +67,7 @@ get_par (gint index)
 {
 	gint i;
 	gint size;
+	gint stops;
 	gchar *par_1;
 	gchar *par_2;
 	gchar *par_i;
@@ -88,7 +90,32 @@ get_par (gint index)
 		par_i = g_strdup_printf ("#%i\n", index);
 	}
 	else
-		par_i = g_strndup (par_1, size);
+	{
+		stops = 0;
+		for (i = 1; i < size; i++)
+			if (par_1[i] == ' ')
+			       if (par_1[i - 1] == '.' || par_1[i - 1] == '!' || par_1[i - 1] == '?')
+					stops++;
+		par_i = g_malloc (size + stops + 10);
+		strncpy (par_i, par_1, size);
+		par_i[size] = '\0';
+		//g_message ("Paragraph %i: %i stops", index, stops);
+
+		if (main_preferences_get_boolean ("tutor", "double_spaces"))
+		{
+			for (i = 0; i < size - 1; i++)
+			{
+				if (par_i[i + 1] == ' ' && par_i[i + 2] != ' ')
+					if (par_i[i] == '.' || par_i[i] == '!' || par_i[i] == '?')
+					{
+						memmove (par_i + i + 3, par_i + i + 2, size - i - 1);
+						par_i[i+2] = ' ';
+						i += 2;
+						size++;
+					}
+			}
+		}
+	}
 
 	size = strlen (par_i);
 	if (size > 0)
@@ -121,7 +148,7 @@ fluid_init ()
 		if (main_preferences_exist ("tutor", "paragraph_list"))
 		{
 			tmp_str = main_preferences_get_string ("tutor", "paragraph_list");
-			tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, tmp_str, ".paragraphs", NULL);
+			tmp_name = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, tmp_str, ".paragraphs", NULL);
 			if ((fh = (FILE *) g_fopen (tmp_name, "r")))
 			{
 				fluid_init_paragraph_list (tmp_str);
@@ -151,7 +178,7 @@ fluid_init_paragraph_list (gchar * list_name)
 	if (list_name && !g_str_equal (list_name, OTHER_DEFAULT))
 	{
 		main_preferences_set_string ("tutor", "paragraph_list", list_name);
-		tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, list_name, ".paragraphs", NULL);
+		tmp_name = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, list_name, ".paragraphs", NULL);
 		g_message ("loading text file: %s.paragraphs", list_name);
 		strncpy (par.name, list_name, 20);
 		par.name[20] = '\0';
@@ -160,7 +187,7 @@ fluid_init_paragraph_list (gchar * list_name)
 	{
 		main_preferences_remove ("tutor", "paragraph_list");
 		tmp_code = main_preferences_get_string ("interface", "language");
-		tmp_name = g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, tmp_code, ".paragraphs", NULL);
+		tmp_name = g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, tmp_code, ".paragraphs", NULL);
 		g_message ("loading text file: %s.paragraphs", tmp_code);
 		strcpy (par.name, "Default");
 		g_free (tmp_code);
@@ -382,7 +409,7 @@ fluid_text_write_to_file (gchar * text_raw)
 	FILE *fh_destiny;
 
 	pars_name = g_strdup_printf ("(%s)", _("Pasted_or_dropped"));
-	pars_path = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, pars_name, ".paragraphs", NULL);
+	pars_path = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, pars_name, ".paragraphs", NULL);
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (pars_path, "w")))
 	{
@@ -438,7 +465,7 @@ fluid_copy_text_file (gchar * file_name)
 	}
 
 	pars_name = g_strdup (strrchr (file_name, DIRSEP) + 1);
-	pars_path = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, pars_name, ".paragraphs", NULL);
+	pars_path = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, pars_name, ".paragraphs", NULL);
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (pars_path, "w")))
 	{
@@ -483,9 +510,14 @@ fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness)
 	 * Comments
 	 */
 	if (accuracy < tutor_goal_accuracy ())
+	{
+		/*
 		tmp_str = g_strdup_printf (_(" Your accuracy rate is not good enough.\n"
 				   " I want it greater than %.0f%%.\n"), tutor_goal_accuracy ());
-	else if (velocity < tutor_goal_accuracy ())
+		*/
+		tmp_str = g_strdup (":-(\n");
+	}
+	else if (velocity < tutor_goal_speed ())
 		tmp_str = g_strdup_printf (_(" You type accurately but not so fast.\n"
 				   " Can you reach %.0f WPM?\n"), tutor_goal_speed ());
 	else if (fluidness < FLUID_1)
@@ -494,7 +526,7 @@ fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness)
 	else if (fluidness < FLUID_2)
 		tmp_str = g_strdup_printf (_(" You are almost getting there. Type more fluently.\n"
 				      " I want a fluidness greater than %.0f%%.\n"), FLUID_2);
-	else if (velocity < 71)
+	else if (velocity < 90)
 		tmp_str = g_strdup (_(" Congratulations!\n"
 				      " It seems to me that you are a professional.\n"
 				      " You don't need this program (me) anymore.\n"
