@@ -27,6 +27,10 @@
 
 #define KEY_DX 35
 #define KEY_DY 35
+
+extern gchar *KEYB_CUSTOM;
+extern gchar *KEYB_EDIT;
+
 static struct
 {
 	gchar *name;
@@ -54,9 +58,6 @@ static struct
 	gint n_cust;
 } layouts;
 
-extern gchar *KEYB_CUSTOM;
-extern gchar *KEYB_EDIT;
-
 /* Constants
  */
 const gunichar vowels[] = {
@@ -157,13 +158,6 @@ keyb_set_name (const gchar * name)
 	keyb.name = g_strdup (name);
 }
 
-gchar *
-keyb_name_last_restore ()
-{
-	g_free (keyb.name);
-	keyb.name = g_strdup (keyb.name_last);
-}
-
 void
 keyb_init_name (const gchar * name)
 {
@@ -273,18 +267,17 @@ keyb_set_chars ()
 	glong n_itens;
 	gunichar *uchs;
 	FILE *fh;
-	GtkWidget *wg;
 
 	/* Search at home
 	 */
-	tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, keyb.name, ".kbd", NULL);
+	tmp_name = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, keyb.name, ".kbd", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "r");
 	if (fh == NULL)
 	{
 		/* Search at data
 		 */
 		g_free (tmp_name);
-		tmp_name = g_strconcat (main_get_data_path (), G_DIR_SEPARATOR_S, keyb.name, ".kbd", NULL);
+		tmp_name = g_strconcat (main_path_data (), G_DIR_SEPARATOR_S, keyb.name, ".kbd", NULL);
 		fh = (FILE *) g_fopen (tmp_name, "r");
 	}
 	g_free (tmp_name);
@@ -500,7 +493,7 @@ keyb_save_new_layout ()
 	FILE *fh;
 
 	assert_user_dir ();
-	tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, keyb.name, ".kbd", NULL);
+	tmp_name = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, keyb.name, ".kbd", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "w");
 	g_free (tmp_name);
 
@@ -539,7 +532,7 @@ keyb_remove_user_layout ()
 	active = gtk_combo_box_get_active (cmb);
 	gtk_combo_box_remove_text (cmb, active);
 
-	tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S, aux, ".kbd", NULL);
+	tmp_name = g_strconcat (main_path_user (), G_DIR_SEPARATOR_S, aux, ".kbd", NULL);
 	g_unlink (tmp_name);
 	g_free (tmp_name);
 
@@ -586,7 +579,6 @@ GList *
 keyb_get_layout_list_from_path (gchar *path)
 {
 	gsize name_len;
-	gchar *tmp;
 	GDir *dir = NULL;
 	gchar *dentry = NULL;
 	GList *files = NULL;
@@ -675,19 +667,17 @@ keyb_set_keyboard_layouts ()
 	static gboolean init = FALSE;
 	gchar *data;
 	gint i;
-	gsize name_len;
 	GList *files;
-	GtkWidget *wg = NULL;
 
 	if (! init)
 	{
 
 		/* Read original layouts just once, now.
 		 */
-		files = keyb_get_layout_list_from_path (main_get_data_path ());
+		files = keyb_get_layout_list_from_path (main_path_data ());
 		layouts.n_orig = g_list_length (files);
 		layouts.orig = g_malloc (layouts.n_orig * sizeof (KeybLayout));
-		//g_printf ("==> Data dir: %s\n", main_get_data_path ());
+		//g_printf ("==> Data dir: %s\n", main_path_data ());
 		for (i = 0; i < layouts.n_orig; i++)
 		{
 			data = g_list_nth_data (files, i);
@@ -712,7 +702,7 @@ keyb_set_keyboard_layouts ()
 	for (i = 0; i < layouts.n_cust; i++)
 		g_free (layouts.cust[i].name);
 	assert_user_dir ();
-	files = keyb_get_layout_list_from_path (main_get_user_dir ());
+	files = keyb_get_layout_list_from_path (main_path_user ());
 	layouts.n_cust = g_list_length (files);
 	if (layouts.n_cust == 0)
 		return;
@@ -930,7 +920,6 @@ keyb_set_combo_kbd (gchar *cmb_country, gchar *cmb_variant)
 	gchar *tmp;
 	gint i, j;
 	GtkComboBox *cmb;
-	GtkTreeModel *tmdl;
 
 	callbacks_shield_set (TRUE);
 	
@@ -979,7 +968,7 @@ keyb_set_combo_kbd (gchar *cmb_country, gchar *cmb_variant)
 void
 keyb_update_combos (gchar *cmb_country, gchar *cmb_variant)
 {
-	gint i, j;
+	gint i;
 	GtkComboBox *cmb;
 
 	callbacks_shield_set (TRUE);
@@ -1102,7 +1091,7 @@ keyb_intro_step (gint step)
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (get_wg ("textview_keyboard")));
 
-	intro00 = g_strdup_printf ("%s %i", _("Step"), step);
+	intro00 = g_strdup_printf (_("Step %i"), step);
 	switch (step)
 	{
 	case 0: /* Recommendations */
@@ -1227,7 +1216,6 @@ keyb_intro_step (gint step)
 void
 keyb_mode_intro ()
 {
-	gchar * text;
 	gchar *country;
 	gchar *variant;
 	gchar *tit;
@@ -1271,7 +1259,6 @@ keyb_mode_hint ()
 	gchar *country;
 	gchar *variant;
 	gchar *tit;
-	GtkWidget *wg;
 
 	keyb_update_virtual_layout ();
 	gtk_widget_hide (get_wg ("window_hints"));
@@ -1310,7 +1297,6 @@ keyb_mode_hint ()
 void
 keyb_mode_edit ()
 {
-	GtkWidget *wg;
 	gchar *tmp;
 
 	/* Save the current name as 'name_last' */
@@ -1356,7 +1342,6 @@ keyb_set_sensitive (gboolean state)
 {
 	gint i, j;
 	gint j_max;
-	gchar *tmp;
 
 	for (i = 0; i < 4; i++)
 	{
@@ -1398,8 +1383,6 @@ keyb_button_match (GtkButton * button)
 void
 keyb_edit_button (GtkButton * button)
 {
-	gint pos = 0;
-
 	if (! keyb_button_match (button))
 		return;
 
@@ -1543,7 +1526,7 @@ hints_init ()
 	if (hints_is_initialized == TRUE)
 		return;
 
-	tmp_name = g_build_filename (main_get_data_path (), "fingers_position.txt", NULL);
+	tmp_name = g_build_filename (main_path_data (), "fingers_position.txt", NULL);
 	fh = (FILE *) g_fopen (tmp_name, "r");
 	if (fh)
 	{
@@ -1694,8 +1677,6 @@ hints_update_from_button (GtkButton *button)
 {
 	gchar *pix_name;
 	gchar ch;
-	gint key_lin;
-	gint key_col;
 
 	hints_init (); // if already initialized, do nothing
 
@@ -1715,7 +1696,7 @@ hints_update_from_button (GtkButton *button)
 	else
 		pix_name = g_strdup ("hands_0.png");
 
-	main_set_pixmap ("pixmap_hints_fixed", pix_name);
+	set_pixmap ("pixmap_hints_fixed", pix_name);
 	g_free (pix_name);
 }
 
@@ -1745,7 +1726,7 @@ hints_update_from_char (gunichar character)
 				if (character == keyb.lochars[i][j])
 				{
 					file_name[6] = hints[i][j];
-					main_set_pixmap ("pixmap_hints", file_name);
+					set_pixmap ("pixmap_hints", file_name);
 					return;
 				}
 
@@ -1754,13 +1735,13 @@ hints_update_from_char (gunichar character)
 				if (character == keyb.upchars[i][j])
 				{
 					file_name[6] = hints[i][j];
-					main_set_pixmap ("pixmap_hints", file_name);
+					set_pixmap ("pixmap_hints", file_name);
 					return;
 				}
 		file_name[6] = '0';
 	}
 
-	main_set_pixmap ("pixmap_hints", file_name);
+	set_pixmap ("pixmap_hints", file_name);
 }
 
 gboolean
@@ -1777,6 +1758,7 @@ hints_demo_fingers_move (gpointer data)
 	for (i = 0; i < 500; i++)
 		if (keyb_edit_next ())
 			break;
+	return TRUE;
 }
 
 void
