@@ -26,12 +26,14 @@
 #include <gtkdatabox_grid.h>
 #include <gtkdatabox_lines.h>
 #include <gtkdatabox_points.h>
+#include <gtkdatabox_bars.h>
 
 #include "auxiliar.h"
 #include "main.h"
 #include "callbacks.h"
 #include "tutor.h"
 #include "basic.h"
+#include "accuracy.h"
 #include "plot.h"
 
 static struct
@@ -82,6 +84,7 @@ gchar hour[DATA_POINTS+1][20];
 gint nchars[DATA_POINTS+1];
 gchar lesson[DATA_POINTS+1][299];
 glong n_points;
+gint plot_type;
 
 /*******************************************************************************
  * Interface functions
@@ -94,7 +97,6 @@ plot_get_databox ()
 
 /*******************************************************************************
  * Private functions
- */
 static void
 plot_clip_data (gint i)
 {
@@ -113,6 +115,73 @@ plot_clip_data (gint i)
 		if (score[i] < 0)
 			score[i] = -0.1;
 }
+ */
+
+static void
+plot_error_frequencies ()
+{
+	gint i;
+	GdkColor color, color2;
+	GdkColor color_black;
+	GtkDatabox *box;
+
+	box = GTK_DATABOX (plot.databox);
+	n_points = accur_n_get ();
+	if (n_points < 1)
+		return;
+	accur_sort ();
+	for (i = 0; i < DATA_POINTS; i++)
+	{
+		if (i < n_points)
+			plot.data.y[i] = accur_wrong_get (i);
+		else
+			plot.data.y[i] = 0;
+	}
+
+	/* Format the chart
+	 */
+	plot.mark.x[0] = -7;
+	plot.mark.y[0] = -7;
+	plot.lim.x[0] = 0;
+	plot.lim.x[1] = DATA_POINTS + 2;
+	plot.lim.y[0] = 0;
+	plot.lim.y[1] = 1.05 * accur_wrong_get (0);
+	if (plot.lim.y[1] < 1)
+		plot.lim.y[1] = 1.05;
+
+	/* White background
+	 */
+	gdk_color_parse ("#ffffff", &color);
+	gtk_widget_modify_bg (plot.databox, GTK_STATE_NORMAL, &color);
+	 
+	gdk_color_parse ("#000000", &color_black);
+	gdk_color_parse (PLOT_GREEN_2, &color);
+	gdk_color_parse (PLOT_RED_2, &color2);
+
+	/* Point limits */
+	plot.limits = gtk_databox_points_new (2, plot.lim.x, plot.lim.y, &color_black, 1);
+	gtk_databox_graph_add (box, plot.limits);
+	gtk_databox_auto_rescale (box, 0.0);
+
+	/* Bar kernel
+	 */
+	plot.point_kernel = gtk_databox_bars_new (i, plot.data.x, plot.data.y, &color, 5);
+	gtk_databox_graph_add (box, plot.point_kernel);
+
+	/* Bar frame
+	 */
+	plot.point_frame = gtk_databox_bars_new (i, plot.data.x, plot.data.y, &color_black, 7);
+	gtk_databox_graph_add (box, plot.point_frame);
+
+	/* Data marker
+	 */
+	plot.point_marker = gtk_databox_points_new (1, plot.mark.x, plot.mark.y, &color_black, 7);
+	gtk_databox_graph_add (box, plot.point_marker);
+
+	/* Redraw the plot
+	 */
+	gtk_widget_show_all (plot.table);
+}
 
 /*******************************************************************************
  * Functions to manage the plottings on the progress window
@@ -122,7 +191,6 @@ plot_initialize ()
 {
 	static gboolean inited = FALSE;
 	gint i;
-	GdkColor color;
 
 	if (inited)
 		return;
@@ -149,16 +217,13 @@ void
 plot_draw_chart (gint field)
 {
 	gint i;
-	gint index;
 	gint lesson_n;
-	gchar *tmp;
 	gchar *tmp_locale;
 	gchar *tmp_name;
 	gchar tmp_str[2000];
 	FILE *fh;
 	GdkColor color, color2, color3;
 	GdkColor color_black;
-	GtkWidget *wg;
 	GtkDatabox *box;
 
 	box = GTK_DATABOX (plot.databox);
@@ -168,6 +233,16 @@ plot_draw_chart (gint field)
 	gtk_databox_graph_remove_all (box);
 	gtk_widget_hide (plot.table);
 
+	plot_type = field;
+
+	/* Error frequencies
+	 */
+	if (field == 6)
+	{
+		plot_error_frequencies ();
+		return;
+	}
+
 	/* Auxiliar variable to track the lesson to be plot
 	 */
 	lesson_n = gtk_spin_button_get_value (GTK_SPIN_BUTTON (get_wg ("spinbutton_stat_lesson")));
@@ -185,11 +260,11 @@ plot_draw_chart (gint field)
 
 	/* Get the file name
 	 */
-	if (field != 4)
-		tmp_name = g_strconcat (main_get_user_dir (), G_DIR_SEPARATOR_S "stat_",
+	if (field < 4)
+		tmp_name = g_strconcat (main_path_stats (), G_DIR_SEPARATOR_S "stat_",
 			       	tutor_get_type_name (), ".txt", NULL);
 	else
-		tmp_name = g_build_filename (main_get_user_dir (), "scores_fluid.txt", NULL);
+		tmp_name = g_build_filename (main_path_stats (), "scores_fluid.txt", NULL);
 
 	/* Open the data file
 	 */
@@ -450,7 +525,7 @@ plot_draw_chart (gint field)
 }
 
 void
-plot_pointer_update (gdouble x, gdouble y)
+plot_pointer_update (gdouble x)
 {
 	static glong n_prev = 0;
 	glong n = 0;
@@ -470,15 +545,23 @@ plot_pointer_update (gdouble x, gdouble y)
 
 	if (n < 0 || n >= n_points || n >= DATA_POINTS) 
 	{
-		xstr = g_strdup_printf ("");
-		ystr = g_strdup_printf ("");
+		xstr = g_strdup ("");
+		ystr = g_strdup ("");
 		plot.mark.x[0] = -7;
 		plot.mark.y[0] = -7;
 	}
 	else
 	{
-		xstr = g_strdup_printf ("%s - %s", date[n], hour[n]);
-		ystr = g_strdup_printf ("%.2f", plot.data.y[n]);
+		if (plot_type < 6)
+		{
+			xstr = g_strdup_printf ("%s - %s", date[n], hour[n]);
+			ystr = g_strdup_printf ("%.2f", plot.data.y[n]);
+		}
+		else
+		{
+			xstr = accur_char_utf8 (n);
+			ystr = g_strdup_printf ("%.0f/%.lu", plot.data.y[n], accur_error_total ());
+		}
 		plot.mark.x[0] = plot.data.x[n];
 		plot.mark.y[0] = plot.data.y[n];
 	}
