@@ -112,36 +112,18 @@ top10_init ()
 	str = g_strdup_printf ("2 - %s", _("Adaptability"));
 	gtk_combo_box_append_text (cmb, str);
 	g_free (str);
-	str = g_strdup_printf ("3 - %s", _("Velocity"));
+	str = g_strdup_printf ("3 - %s", _("Speed"));
 	gtk_combo_box_append_text (cmb, str);
 	g_free (str);
-	str = g_strdup_printf ("4 - %s", _("Fluidness"));
+	str = g_strdup_printf ("4 - %s", _("Fluidity"));
 	gtk_combo_box_append_text (cmb, str);
 	g_free (str);
 }
 
-static void
-top10_check_writable (gchar *scorefile)
-{
-	gchar *path;
-
-	path = g_build_filename ("/var/games/klavaro", scorefile, NULL);
-	if (!g_file_test (path, G_FILE_TEST_IS_REGULAR))
-	{
-		g_free (path);
-		return;
-	}
-#ifdef	G_OS_UNIX
-	g_chmod (path, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH);
-#endif
-	g_free (path);
-}
-
 void
 top10_message (gchar * msg)
 {
 	static gboolean init = TRUE;
-	GtkWidget *wg;
 
 	if (!init)
 		gtk_statusbar_pop (GTK_STATUSBAR (get_wg ("statusbar_top10_message")), 0);
@@ -269,7 +251,7 @@ top10_delete_stat (gint i, gboolean locally)
 }
 
 gfloat
-top10_calc_score (Statistics * stat)
+top10_calc_score_old (Statistics * stat)
 {
 	gfloat score;
 	// Don't touch this anymore!
@@ -277,6 +259,15 @@ top10_calc_score (Statistics * stat)
 	return (score);
 }
 
+gfloat
+top10_calc_score (Statistics * stat)
+{
+	gfloat score;
+	// Don't touch this anymore! (touched: new_WPM = 1.2 old_WPM)
+	score = (6 * stat->velo / 1.2 + 3 * stat->accur + stat->fluid) / 100;
+	return (score);
+}
+
 gboolean
 top10_validate_stat (Statistics * stat)
 {
@@ -287,7 +278,7 @@ top10_validate_stat (Statistics * stat)
 		return (FALSE);
 	}
 
-	if ((stat->score - top10_calc_score (stat) > 1.0e-4))
+	if ((stat->score - top10_calc_score (stat) > 1.0e-5) && (stat->score - top10_calc_score_old (stat) > 1.0e-5))
 	{
 		g_message ("Invalid score (%g): did you try to edit the scores file?", stat->score);
 		return (FALSE);
@@ -326,6 +317,114 @@ top10_get_score_file (gboolean locally, gint lang)
 	return (ksc);
 }
 
+static void
+top10_merge_stats_from_file (gchar * file)
+{
+	gint i, j, n;
+	FILE *fh;
+	Statistics top10;
+
+	fh = g_fopen (file, "r");
+	if (fh == NULL)
+		return;
+
+	for (i = 0; i < 10; i++)
+	{
+		/* lang[0] */
+		top10.lang[0] = getc (fh);
+		if (!g_ascii_isalpha (top10.lang[0]))
+		{
+			g_message ("Problem: lang[0] = %c", top10.lang[0]);
+			break;
+		}
+
+		/* lang[1] */
+		top10.lang[1] = getc (fh);
+		if (!g_ascii_isalpha (top10.lang[1]))
+		{
+			top10.lang[0] = 'e';
+			top10.lang[1] = 'o';
+		}
+
+		/* genv */
+		top10.genv = getc (fh);
+		if (top10.genv != 'x' && top10.genv != 'w')
+		{
+			g_message ("Problem: genv = %c", top10.genv);
+			break;
+		}
+
+		/* when */
+		n = fread (&top10.when, sizeof (time_t), 1, fh);
+		if (n == 0)
+		{
+			g_message ("Problem: when = %lu", top10.when);
+			break;
+		}
+
+		/* nchars */
+		n = fread (&top10.nchars, sizeof (gint), 1, fh);
+		if (n == 0 || top10.nchars < MIN_CHARS_TO_LOG)
+		{
+			g_message ("Problem: nchars = %i, < %i", top10.nchars, MIN_CHARS_TO_LOG);
+			break;
+		}
+
+		/* accur */
+		n = fread (&top10.accur, sizeof (gfloat), 1, fh);
+		if (n == 0 || top10.accur < 0 || top10.accur > 100)
+		{
+			g_message ("Problem: accur = %f <> [0, 100]", top10.accur);
+			break;
+		}
+
+		/* velo */
+		n = fread (&top10.velo, sizeof (gfloat), 1, fh);
+		if (n == 0 || top10.velo < 0 || top10.velo > 300)
+		{
+			g_message ("Problem: velo = %f <> [0, 300]", top10.velo);
+			break;
+		}
+
+		/* fluid */
+		n = fread (&top10.fluid, sizeof (gfloat), 1, fh);
+		if (n == 0 || top10.fluid < 0 || top10.fluid > 100)
+		{
+			g_message ("Problem: fluid = %f <> [0, 100]", top10.fluid);
+			break;
+		}
+
+		/* score */
+		n = fread (&top10.score, sizeof (gfloat), 1, fh);
+		if (n == 0 || top10.score < 0 || top10.score > 20)
+		{
+			g_message ("Problem: score = %f <> [0, 20]", top10.score);
+			break;
+		}
+
+		/* name_len */
+		n = fread (&top10.name_len, sizeof (gint), 1, fh);
+		if (n == 0 || top10.name_len < 0 || top10.name_len > MAX_NAME_LEN)
+		{
+			g_message ("Problem: name_len = %i <> [0, MAX_NAME_LEN]", top10.name_len);
+			break;
+		}
+
+		/* name */
+		n = fread (&top10.name, sizeof (gchar), top10.name_len, fh);
+		top10.name[top10.name_len] = '\0';
+		if (!g_utf8_validate (top10.name, -1, NULL))
+		{
+			for (j = 0; j < top10.name_len; j++)
+				if (!g_ascii_isalpha (top10.name[j]))
+					top10.name[j] = '?';
+		}
+
+		top10_compare_insert_stat (&top10, TRUE);
+	}
+	fclose (fh);
+}
+
 gboolean
 top10_read_stats_from_file (gboolean locally, gchar * file)
 {
@@ -445,6 +544,10 @@ top10_read_stats (gboolean locally, gint lang)
 {
 	gchar *local_ksc;
 	gchar *tmp;
+	gchar *uname;
+	gchar *stat_dir;
+	gboolean success;
+	GDir *home;
 	Statistics *top10;
 
 	top10 = locally ? top10_local : top10_global;
@@ -453,9 +556,7 @@ top10_read_stats (gboolean locally, gint lang)
 
 	local_ksc = top10_get_score_file (locally, lang);
 
-	tmp = g_build_filename (main_get_score_path (), local_ksc, NULL);
-	g_free (local_ksc);
-
+	tmp = g_build_filename (main_path_score (), local_ksc, NULL);
 	if (!top10_read_stats_from_file (locally, tmp))
 	{
 		g_message ("Could not read the scores file '%s'.\n Creating a blank one.", tmp);
@@ -463,46 +564,78 @@ top10_read_stats (gboolean locally, gint lang)
 		top10_write_stats (locally, lang);
 	}
 	g_free (tmp);
+
+	if (!locally)
+	{
+		g_free (local_ksc);
+		return;
+	}
+
+	/* Go search other users' subdirs
+	 */
+	tmp = strchr (main_path_stats (), G_DIR_SEPARATOR);
+	if (tmp)
+	       	tmp = strchr (tmp + 1, G_DIR_SEPARATOR);
+	if (tmp)
+	       	tmp = strchr (tmp + 1, G_DIR_SEPARATOR);
+	if (tmp)
+	{
+	       	stat_dir = tmp + 1;
+		home = g_dir_open ("/home", 0, NULL);
+	}
+	else
+	       	home = NULL;
+
+	success = FALSE;
+	if (home)
+	{
+		while ((uname = (gchar*) g_dir_read_name (home)))
+		{
+			if (g_str_equal (uname, "root"))
+				continue;
+			if (g_str_equal (uname, "lost+found"))
+				continue;
+			if (g_str_equal (uname, g_get_user_name ()))
+				continue;
+
+			tmp = g_build_filename ("/home", uname, stat_dir, "ksc", local_ksc, NULL);
+			if (g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
+			{
+				top10_merge_stats_from_file (tmp);
+				success = TRUE;
+			}
+			g_free (tmp);
+		}
+		g_dir_close (home);
+	}
+	g_free (local_ksc);
+
+	if (success)
+		top10_write_stats (TRUE, -1);
 }
 
 void
 top10_write_stats (gboolean locally, gint lang)
 {
 	gint i;
-	gchar *path;
 	gchar *filename;
 	gchar *lsfile;
-	gchar *command;
 	FILE *fh;
-	gboolean success;
-	GError *error = NULL;
 	Statistics *top10;
 
 	top10 = locally ? top10_local : top10_global;
 
-	if (UNIX_OK)
-		path = g_strdup ("/tmp/klavaro");
-	else
-		path = g_strdup (main_get_score_path ());
-
-	if (!g_file_test (path, G_FILE_TEST_IS_DIR))
-	{
-#ifdef G_OS_UNIX
-		g_mkdir (path, S_IRWXU | S_IRWXG | S_IRWXO | S_IWGRP | S_IWOTH);
-#else
-		g_mkdir (path, 0xFFFF);
-#endif
-	}
+	if (!g_file_test (main_path_score (), G_FILE_TEST_IS_DIR))
+		g_mkdir_with_parents (main_path_score (), DIR_PERM);
 
 	filename = top10_get_score_file (locally, lang);
 
-	lsfile = g_build_filename (path, filename, NULL);
+	lsfile = g_build_filename (main_path_score (), filename, NULL);
 
 	fh = g_fopen (lsfile, "w");
 	if (fh == NULL)
 	{
-		g_warning ("Could not write the scores file in %s", path);
-		g_free (path);
+		g_warning ("Could not write the scores file in %s", main_path_score ());
 		g_free (filename);
 		g_free (lsfile);
 		return;
@@ -526,31 +659,6 @@ top10_write_stats (gboolean locally, gint lang)
 	fputs ("KLAVARO!", fh);
 	fclose (fh);
 
-	if (UNIX_OK)
-	{
-		top10_check_writable (filename);
-		command = g_strconcat ("klavaro_helper ", filename, NULL);
-		success = g_spawn_command_line_sync (command, NULL, NULL, NULL, &error);
-		if (!success)
-		{
-			g_free (command);
-			command = g_strconcat ("./klavaro_helper ", filename, NULL);
-			success = g_spawn_command_line_sync (command, NULL, NULL, NULL, NULL);
-		}
-		g_free (command);
-		if (success)
-		{
-			g_unlink (lsfile);
-			g_rmdir (path);
-			top10_check_writable (filename);
-		}
-		else
-			g_message ("Failed to copy scorings file.\n %s", error->message);
-		if (error != NULL)
-			g_error_free (error);
-	}
-
-	g_free (path);
 	g_free (filename);
 	g_free (lsfile);
 }
@@ -680,17 +788,14 @@ top10_show_stats (gboolean locally)
 	}
 }
 
-#ifdef G_OS_UNIX
 gboolean
 top10_global_update (gpointer data)
 {
-	gboolean success;
 	gboolean fail;
 	gchar *tmp;
 	gchar *ksc;
 	gchar *host;
 	gchar *command;
-	GError *error = NULL;
 	GtkImage *img;
 	gpointer gp;
 	CURL *curl;
@@ -700,7 +805,7 @@ top10_global_update (gpointer data)
 	img = GTK_IMAGE (get_wg ("image_top10_update"));
 	top10_message (NULL);
 
-	if (!main_get_curl_ok ())
+	if (!main_curl_ok ())
 	{
 		tmp = g_strconcat (_("Not able to download files"), ": 'libcurl' ", _("not found"), ". ",
 		       _("Are you sure you have it installed in your system?"), NULL);
@@ -722,15 +827,10 @@ top10_global_update (gpointer data)
 		g_free (host);
 		return FALSE;
 	}
-	tmp = g_strdup ("/tmp/klavaro");
-	if (!g_file_test (tmp, G_FILE_TEST_IS_DIR))
-#ifdef G_OS_UNIX
-		g_mkdir (tmp, S_IRWXU | S_IRWXG | S_IRWXO | S_IWGRP | S_IWOTH);
-#else
-		g_mkdir (tmp, 0xFFFF);
-#endif
-	g_free (tmp);
-	tmp = g_build_filename ("/tmp/klavaro", ksc, NULL);
+
+	if (!g_file_test (main_path_score (), G_FILE_TEST_IS_DIR))
+		g_mkdir_with_parents (main_path_score (), DIR_PERM);
+	tmp = g_build_filename (main_path_score (), ksc, NULL);
 	fail = TRUE;
 	command = g_strdup_printf ("http://%s/%s", host, ksc);
 	if ( (fh = g_fopen (tmp, "wb")) )
@@ -754,46 +854,20 @@ top10_global_update (gpointer data)
 		gtk_image_set_from_stock (img, "gtk-goto-bottom", GTK_ICON_SIZE_BUTTON);
 		g_free (ksc);
 		g_free (tmp);
-		g_rmdir ("/tmp/klavaro");
 		return FALSE;
 	}
 
-	success = g_file_test (tmp, G_FILE_TEST_IS_REGULAR);
-	if (success)
-	{
-		top10_check_writable (ksc);
-		command = g_strconcat ("klavaro_helper ", ksc, NULL);
-		success = g_spawn_command_line_sync (command, NULL, NULL, NULL, &error);
-		if (!success)
-		{
-			g_free (command);
-			command = g_strconcat ("./klavaro_helper ", ksc, NULL);
-			success = g_spawn_command_line_sync (command, NULL, NULL, NULL, NULL);
-		}
-		g_free (command);
-		g_unlink (tmp);
-		if (success)
-		{
-			top10_show_stats (GLOBAL);
-			top10_check_writable (ksc);
-		}
-		else
-		{
-			g_free (tmp);
-			tmp = g_strdup_printf ("%s\n %s", _("Failed to copy scoring file."),
-					       error->message);
-			top10_message (tmp);
-		}
-		if (error != NULL)
-			g_error_free (error);
-	}
-	else
+	if (!g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
 		g_message ("No file downloaded from the host server.");
 
 	gtk_image_set_from_stock (img, "gtk-goto-bottom", GTK_ICON_SIZE_BUTTON);
 	g_free (tmp);
 	g_free (ksc);
-	g_rmdir ("/tmp/klavaro");
+
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (get_wg ("combobox_top10"))) == 0)
+		top10_show_stats (LOCAL);
+	else
+		top10_show_stats (GLOBAL);
 
 	return FALSE;
 }
@@ -801,6 +875,7 @@ top10_global_update (gpointer data)
 gboolean
 top10_global_publish (gpointer data)
 {
+	gint i;
 	gboolean success;
 	gchar *tmp;
 	gchar *ksc;
@@ -819,7 +894,7 @@ top10_global_publish (gpointer data)
 	img = GTK_IMAGE (get_wg ("image_top10_publish"));
 	top10_message (NULL);
 
-	if (!main_get_curl_ok ())
+	if (!main_curl_ok ())
 	{
 		tmp = g_strconcat (_("Not able to upload files"), ": 'libcurl' ", _("not found"), ". ",
 		       _("Are you sure you have it installed in your system?"), NULL);
@@ -847,7 +922,8 @@ top10_global_publish (gpointer data)
 		tmp = g_strdup ("en");
 	}
 	ksc = g_strdup_printf ("local_%c%c.ksc", tmp[0], tmp[1]);
-	path = g_build_filename ("/var/games/klavaro/", ksc, NULL);
+	//path = g_build_filename ("/var/games/klavaro/", ksc, NULL);
+	path = g_build_filename (main_path_score (), ksc, NULL);
 	g_free (ksc);
 	g_stat (path, &fs);
 
@@ -863,6 +939,7 @@ top10_global_publish (gpointer data)
 	g_free (username);
 	g_free (host);
 	g_free (ksc);
+	g_free (tmp);
 
 	//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
 	curl_easy_setopt (curl, CURLOPT_TIMEOUT, TIMEOUT);
@@ -874,7 +951,15 @@ top10_global_publish (gpointer data)
 	success = FALSE;
 	if ( (fh = g_fopen (path, "rb")) )
 	{
-		fh2 = g_fopen ("/tmp/klavaro.html", "wb");
+		i = 0;
+		while (1)
+		{
+			tmp = g_strdup_printf ("%s/klavaro_%03i.html", g_get_tmp_dir (), i++);
+			if ((fh2 = g_fopen (tmp, "wb")))
+				break;
+			g_free (tmp);
+		}
+		g_free (tmp);
 		curl_easy_setopt (curl, CURLOPT_READDATA, fh);
 		curl_easy_setopt (curl, CURLOPT_WRITEDATA, fh2);
 		if (curl_easy_perform (curl))
@@ -887,7 +972,6 @@ top10_global_publish (gpointer data)
 	curl_easy_cleanup (curl);
 	g_free (path);
 	g_free (url);
-	g_free (tmp);
 
 	gtk_image_set_from_stock (img, "gtk-goto-top", GTK_ICON_SIZE_BUTTON);
 
@@ -928,13 +1012,13 @@ top10_global_rank ()
 	CURL *curl2;
 	struct curl_slist *comms = NULL;
 
-	if (!main_get_curl_ok ())
+	if (!main_curl_ok ())
 	{
 		g_warning ("Not able to upload files: 'libcurl' not installed.");
 		return;
 	}
 
-	host = top10_get_host ("uphost");
+	host = top10_get_host ();
 	if (host == NULL)
 	{
 		g_message ("Nothing updated");
@@ -1038,7 +1122,8 @@ top10_global_rank ()
 	 */
 	fail = TRUE;
 	msg = g_strconcat (user, ":", pass, NULL);
-	g_free (user); g_free (pass);
+	g_free (user);
+       	g_free (pass);
 	if (! (curl = curl_easy_init ()) )
 	{
 		g_free (host);
@@ -1047,12 +1132,14 @@ top10_global_rank ()
 	}
 	//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
 	curl_easy_setopt (curl, CURLOPT_USERPWD, msg);
-	g_mkdir ("/tmp/klavaro", S_IRWXU | S_IRWXG | S_IRWXO | S_IWGRP | S_IWOTH);
+	tmp = g_build_filename (g_get_tmp_dir (), "klavaro", NULL);
+	g_mkdir (tmp, DIR_PERM);
+	g_free (tmp);
 	g_printf ("Downloaded:\n");
 	for (i = 0; i < file_len; i++)
 	{
 		command = g_strdup_printf ("ftp://%s/%s", host, file[i]);
-		tmp = g_build_filename ("/tmp/klavaro", file[i], NULL);
+		tmp = g_build_filename (g_get_tmp_dir (), "klavaro", file[i], NULL);
 		if ( (fh = g_fopen (tmp, "wb")) )
 		{
 			curl_easy_setopt (curl, CURLOPT_URL, command);
@@ -1084,7 +1171,7 @@ top10_global_rank ()
 		{
 			if (g_str_has_suffix (file[j], tmp))
 			{
-				ksc = g_build_filename ("/tmp/klavaro", file[j], NULL);
+				ksc = g_build_filename (g_get_tmp_dir (), "klavaro", file[j], NULL);
 				if (!top10_read_stats_from_file (LOCAL, ksc))
 					g_message ("Invalid file: %s", ksc);
 				else
@@ -1100,7 +1187,7 @@ top10_global_rank ()
 						}
 					}
 				}
-				msg = g_build_filename ("/tmp", file[j], NULL);
+				msg = g_build_filename (g_get_tmp_dir (), file[j], NULL);
 				if (g_rename (ksc, msg))
 					g_unlink (ksc);
 				g_free (ksc);
@@ -1111,11 +1198,13 @@ top10_global_rank ()
 		if (success)
 			top10_write_stats (GLOBAL, i);
 	}
-	g_rmdir ("/tmp/klavaro");
+	tmp = g_build_filename (g_get_tmp_dir (), "klavaro", NULL);
+	g_rmdir (tmp);
+	g_free (tmp);
 
 	/* Upload new rankings to download host
 	 */
-	hostsub = top10_get_host ("downhost");
+	hostsub = top10_get_host ();
 	if (hostsub == NULL)
 	{
 		g_message ("Nothing updated");
@@ -1183,7 +1272,7 @@ top10_global_rank ()
 			continue;
 
 		msg = g_strconcat ("global_", trans_get_code (i), ".ksc", NULL);
-		ksc = g_strconcat ("/var/games/klavaro/", msg, NULL);
+		ksc = g_build_filename (main_path_score (), msg, NULL);
 		command = g_strdup_printf ("ftp://%s/%s", host, msg);
 		command2 = g_strdup_printf ("http://" CGI_SERVER "?dosiernomo=%s&lingvo=%s", msg, trans_get_code (i));
 		success = FALSE;
@@ -1221,7 +1310,7 @@ top10_global_rank ()
 
 	/* Remove downloaded files in uphost
 	 */
-	host = top10_get_host ("uphost");
+	host = top10_get_host ();
 	if (host == NULL)
 	{
 		g_message ("Nothing updated");
@@ -1280,7 +1369,7 @@ top10_global_rank ()
 }
 
 gchar *
-top10_get_host (gchar * updown)
+top10_get_host ()
 {
 	gchar *tmp;
 	gchar *host = NULL;
@@ -1363,7 +1452,7 @@ top10_get_pass (gchar * updown)
 
 	if (g_str_equal (updown, "downpass"))
 	{
-		tmp = g_build_filename (main_get_user_dir (), "adm.txt", NULL);
+		tmp = g_build_filename (main_path_user (), "adm.txt", NULL);
 		if (! g_file_get_contents (tmp, &pass, NULL, NULL))
 		{
 			g_free (tmp);
@@ -1423,7 +1512,7 @@ top10_keyfile_proverbaro ()
 	if (keyfile == NULL)
 		keyfile = g_key_file_new ();
 
-	tmp = g_build_filename (main_get_user_dir (), "proverbaro.desktop", NULL);
+	tmp = g_build_filename (main_path_user (), "proverbaro.desktop", NULL);
 	if (!g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
 	{
 		fh = g_fopen (tmp, "wb");
@@ -1458,4 +1547,3 @@ top10_keyfile_proverbaro ()
 	g_free (tmp);
 	return TRUE;
 }
-#endif
