@@ -81,7 +81,7 @@ gboolean top10_global_publish (gpointer data);
 
 void top10_global_rank (void);
 
-gchar *top10_get_host (gchar * updown);
+gchar *top10_get_host ();
 
 gchar *top10_get_user (gchar * updown);
 
