@@ -54,8 +54,8 @@ trans_code_to_country (gchar *code)
 		{"es","España"},
 		{"fr","France"},
 		{"gr","Ελλάδα"},
+		{"il","ישראל"},
 		{"hu","Magyarország"},
-		{"il","מדינת ישראל"},
 		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
 		{"nb","Norge"},
