@@ -148,7 +148,7 @@ tutor_init (TutorType tt_type)
 	gtk_widget_hide (get_wg ("window_keyboard"));
 	gtk_widget_hide (get_wg ("dialog_info"));
 	gtk_widget_hide (get_wg ("aboutdialog_klavaro"));
-	gtk_widget_hide (get_wg ("kadro_tro_eraroj"));
+	gtk_widget_hide (get_wg ("togglebutton_toomuch_errors"));
 	gtk_widget_show (get_wg ("window_tutor"));
 	gtk_widget_grab_focus (get_wg ("entry_mesg"));
 
@@ -968,8 +968,10 @@ tutor_calc_stats ()
 		 * Coming back to the right locale
 		 */
 		if (tmp_locale != NULL)
+		{
 			setlocale (LC_NUMERIC, tmp_locale);
-		g_free (tmp_locale);
+			g_free (tmp_locale);
+		}
 	}
 
 	/*
@@ -986,6 +988,7 @@ tutor_calc_stats ()
 			       "\n", _("Error ratio:"), " %i/%i\n", _("Accuracy:"), " ", NULL);
 
 	tmp_str2 = g_strdup_printf (tmp_str, minutes, seconds, tutor.n_errors, tutor.n_touchs);
+	g_free (tmp_str);
 	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 
 	// Paint the accuracy
@@ -1113,7 +1116,6 @@ tutor_calc_stats ()
 		}
 		break;
 	}
-	g_free (tmp_str);
 	g_free (tmp_str2);
 
 	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg), gtk_text_buffer_get_insert (buf));
